==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/pt_BR.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Você não pode remover sua própria permissão de leitura.",
    "Team folders" : "Pastas de equipe",
    "Admin configured folders shared with everyone in a team" : "Pastas configuradas pelo administrador compartilhadas com todos em uma equipe",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Pastas configuradas pelo administrador compartilhadas com todos em uma equipe.\n\nAs pastas podem ser configuradas em *Pastas da equipe* nas configurações do administrador.\n\nDepois que uma pasta é criada, o administrador pode conceder acesso à pasta a uma ou mais equipes, controlar suas permissões de gravação/compartilhamento e atribuir uma cota para a pasta.\nA partir do Hub 10/Nextcloud 31, o administrador precisa fazer parte da equipe para poder atribuir a ela uma pasta de equipe.",
    "Unset" : "Redefinir",
    "Denied (Inherited permission)" : "Negado (Permissão herdada)",
    "Allowed (Inherited permission)" : "Permitido (Permissão herdada)",
    "Denied" : "Negado",
    "Allowed" : "Permitido",
    "Access denied" : "Acesso negado",
    "Access allowed" : "Acesso permitido",
    "Inherit permission" : "Herdar permissão",
    "Deny" : "Negar",
    "Allow" : "Permitir",
    "Group" : "Grupo",
    "Team" : "Equipe",
    "Team folder" : "Pasta de equipe",
    "Read" : "Ler",
    "Write" : "Escrever",
    "Create" : "Criar",
    "Delete" : "Excluir",
    "Share" : "Compartilhar",
    "You" : "Você",
    "Remove access rule" : "Excluir regra de acesso",
    "Add advanced permission rule" : "Adicionar regra avançada de permissão",
    "Select a user or group" : "Selecionar um usuário ou grupo",
    "Open Team folder" : "Abra a pasta de Equipe",
    "Permission denied. User does not have sufficient permissions." : "Permissão negada. O usuário não tem permissões suficientes.",
    "Unexpected status from server" : "Status inesperado do servidor",
    "List of Team folders." : "Lista das pastas da Equipe.",
    "No Team folders yet" : "Ainda não há pastas da Equipe",
    "Team folders will show up here" : "As pastas da equipe serão exibidas aqui",
    "Add group" : "Adicionar grupo",
    "Default" : "Padrão",
    "Unlimited" : "Ilimitado",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Deseja realmente excluir \"{folderName}\" e todos os arquivos dentro dela? Esta operação não pode ser desfeita",
    "Delete \"{folderName}\"?" : "Excluir \"{folderName}\"?",
    "Team folder admin delegation" : "Delegação do administrador de pastas de equipe",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "O Nextcloud permite delegar a administração das Pastas de equipe a usuários não administradores.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Especifique abaixo os grupos que terão permissão para gerenciar as Pastas de equipe e usar sua API/REST.",
    "They will have access to all Team folders." : "Eles terão acesso a todas as pastas de equipe.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Especifique abaixo os grupos que terão permissão para gerenciar as Pastas de equipe e usar somente sua API/REST.",
    "They will only have access to Team folders for which they have advanced permissions." : "Eles só terão acesso às pastas de equipe para as quais têm permissões avançadas.",
    "Group or team" : "Grupo ou equipe",
    "Sort by number of groups or teams that have access to this folder" : "Ordenar por número de grupos ou equipes que têm acesso a esta pasta",
    "Sort by number of groups that have access to this folder" : "Ordenar por número de grupos que têm acesso a esta pasta",
    "Folder name" : "Nome da pasta",
    "Quota" : "Cota",
    "Advanced Permissions" : "Permissões avançadas",
    "Pagination of team folders" : "Paginação de pastas de equipe",
    "Previous" : "Anterior",
    "Next" : "Próxima",
    "User" : "Usuário",
    "Unknown" : "Desconhecido",
    "Users/groups that can manage" : "Usuários/grupos que podem gerenciar",
    "None" : "Nenhum",
    "No other groups or teams available" : "Nenhum outro grupo ou equipe disponível",
    "No other groups available" : "Nenhum outro grupo disponível",
    "{displayName} (team)" : "{displayName} (equipe)",
    "Add group or team" : "Adicionar grupo ou equipe",
    "{size} used" : "{size} usado",
    "Other …" : "Outros …",
    "You can not remove your own read permission." : "Você não pode remover sua própria permissão de leitura.",
    "Group folders" : "Pastas de grupo",
    "Admin configured folders shared with everyone in a group" : "Pastas configuradas pelo administrador compartilhadas com todos em um grupo",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Pastas configuradas pelo administrador compartilhadas com todos em um grupo.\n\nAs pastas podem ser configuradas em *Pastas de grupo* nas configurações de administrador.\n\nApós a criação de uma pasta, o administrador pode conceder acesso à pasta a um ou mais grupos, controlar suas permissões de gravação/compartilhamento e atribuir uma cota para a pasta.",
    "Group folder" : "Pasta de grupo",
    "Open group folder" : "Abrir pasta de grupo",
    "List of group folders." : "Lista de pastas de grupo.",
    "No group folders yet" : "Ainda não há pastas de grupo",
    "Group folders will show up here" : "As pastas de grupo aparecerão aqui",
    "Group folder admin delegation" : "Delegação de administrador de pasta de grupo",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "O Nextcloud permite que você delegue a administração de pastas de grupo a usuários não administradores.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Especifique abaixo os grupos que terão permissão para gerenciar pastas de grupos e usar sua API/REST.",
    "They will have access to all group folders." : "Eles terão acesso a todas as pastas de grupo.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Especifique abaixo os grupos que terão permissão para gerenciar pastas de grupos e usar somente sua API/REST.",
    "They will only have access to group folders for which they have advanced permissions." : "Eles só terão acesso às pastas de grupo para as quais tenham permissões avançadas.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Pastas configuradas pelo administrador compartilhadas com todos em uma equipe.\n\nAs pastas podem ser configuradas em *Pastas de equipe* nas configurações do administrador.\n\nDepois que uma pasta é criada, o administrador pode conceder acesso à pasta a uma ou mais equipes, controlar suas permissões de gravação/compartilhamento e atribuir uma cota para a pasta."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/pt_BR.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Você não pode remover sua própria permissão de leitura.",
    "Team folders" : "Pastas de equipe",
    "Unset" : "Redefinir",
    "Denied (Inherited permission)" : "Negado (Permissão herdada)",
    "Allowed (Inherited permission)" : "Permitido (Permissão herdada)",
    "Denied" : "Negado",
    "Allowed" : "Permitido",
    "Access denied" : "Acesso negado",
    "Access allowed" : "Acesso permitido",
    "Inherit permission" : "Herdar permissão",
    "Deny" : "Negar",
    "Allow" : "Permitir",
    "Group" : "Grupo",
    "Team" : "Equipe",
    "Team folder" : "Pasta de equipe",
    "Read" : "Ler",
    "Write" : "Escrever",
    "Create" : "Criar",
    "Delete" : "Excluir",
    "Share" : "Compartilhar",
    "You" : "Você",
    "Remove access rule" : "Excluir regra de acesso",
    "Add advanced permission rule" : "Adicionar regra avançada de permissão",
    "Select a user or group" : "Selecionar um usuário ou grupo",
    "Open Team folder" : "Abra a pasta de Equipe",
    "Permission denied. User does not have sufficient permissions." : "Permissão negada. O usuário não tem permissões suficientes.",
    "Unexpected status from server" : "Status inesperado do servidor",
    "List of Team folders." : "Lista das pastas da Equipe.",
    "No Team folders yet" : "Ainda não há pastas da Equipe",
    "Team folders will show up here" : "As pastas da equipe serão exibidas aqui",
    "Add group" : "Adicionar grupo",
    "Default" : "Padrão",
    "Unlimited" : "Ilimitado",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Deseja realmente excluir \"{folderName}\" e todos os arquivos dentro dela? Esta operação não pode ser desfeita",
    "Delete \"{folderName}\"?" : "Excluir \"{folderName}\"?",
    "Team folder admin delegation" : "Delegação do administrador de pastas de equipe",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "O Nextcloud permite delegar a administração das Pastas de equipe a usuários não administradores.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Especifique abaixo os grupos que terão permissão para gerenciar as Pastas de equipe e usar sua API/REST.",
    "They will have access to all Team folders." : "Eles terão acesso a todas as pastas de equipe.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Especifique abaixo os grupos que terão permissão para gerenciar as Pastas de equipe e usar somente sua API/REST.",
    "They will only have access to Team folders for which they have advanced permissions." : "Eles só terão acesso às pastas de equipe para as quais têm permissões avançadas.",
    "Group or team" : "Grupo ou equipe",
    "Sort by number of groups or teams that have access to this folder" : "Ordenar por número de grupos ou equipes que têm acesso a esta pasta",
    "Sort by number of groups that have access to this folder" : "Ordenar por número de grupos que têm acesso a esta pasta",
    "Folder name" : "Nome da pasta",
    "Quota" : "Cota",
    "Advanced Permissions" : "Permissões avançadas",
    "Pagination of team folders" : "Paginação de pastas de equipe",
    "Previous" : "Anterior",
    "Next" : "Próxima",
    "User" : "Usuário",
    "Unknown" : "Desconhecido",
    "Users/groups that can manage" : "Usuários/grupos que podem gerenciar",
    "None" : "Nenhum",
    "No other groups or teams available" : "Nenhum outro grupo ou equipe disponível",
    "No other groups available" : "Nenhum outro grupo disponível",
    "{displayName} (team)" : "{displayName} (equipe)",
    "Add group or team" : "Adicionar grupo ou equipe",
    "{size} used" : "{size} usado",
    "Other …" : "Outros …",
    "You can not remove your own read permission." : "Você não pode remover sua própria permissão de leitura.",
    "Group folders" : "Pastas de grupo",
    "Admin configured folders shared with everyone in a group" : "Pastas configuradas pelo administrador compartilhadas com todos em um grupo",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Pastas configuradas pelo administrador compartilhadas com todos em um grupo.\n\nAs pastas podem ser configuradas em *Pastas de grupo* nas configurações de administrador.\n\nApós a criação de uma pasta, o administrador pode conceder acesso à pasta a um ou mais grupos, controlar suas permissões de gravação/compartilhamento e atribuir uma cota para a pasta.",
    "Group folder" : "Pasta de grupo",
    "Open group folder" : "Abrir pasta de grupo",
    "List of group folders." : "Lista de pastas de grupo.",
    "No group folders yet" : "Ainda não há pastas de grupo",
    "Group folders will show up here" : "As pastas de grupo aparecerão aqui",
    "Group folder admin delegation" : "Delegação de administrador de pasta de grupo",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "O Nextcloud permite que você delegue a administração de pastas de grupo a usuários não administradores.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Especifique abaixo os grupos que terão permissão para gerenciar pastas de grupos e usar sua API/REST.",
    "They will have access to all group folders." : "Eles terão acesso a todas as pastas de grupo.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Especifique abaixo os grupos que terão permissão para gerenciar pastas de grupos e usar somente sua API/REST.",
    "They will only have access to group folders for which they have advanced permissions." : "Eles só terão acesso às pastas de grupo para as quais tenham permissões avançadas.",
    "Admin configured folders shared with everyone in a team" : "Pastas configuradas pelo administrador compartilhadas com todos em uma equipe",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Pastas configuradas pelo administrador compartilhadas com todos em uma equipe.\n\nAs pastas podem ser configuradas em *Pastas de equipe* nas configurações do administrador.\n\nDepois que uma pasta é criada, o administrador pode conceder acesso à pasta a uma ou mais equipes, controlar suas permissões de gravação/compartilhamento e atribuir uma cota para a pasta.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Pastas configuradas pelo administrador compartilhadas com todos em uma equipe.\n\nAs pastas podem ser configuradas em *Pastas da equipe* nas configurações do administrador.\n\nDepois que uma pasta é criada, o administrador pode conceder acesso à pasta a uma ou mais equipes, controlar suas permissões de gravação/compartilhamento e atribuir uma cota para a pasta.\nA partir do Hub 10/Nextcloud 31, o administrador precisa fazer parte da equipe para poder atribuir a ela uma pasta de equipe."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
